@@ -40,16 +40,16 @@ CAR_KEYPOINTS_24 = [
 ]
 
 SKELETON_ORIG = [
-    [49, 46], [49, 8], [49, 57], [8, 0], [8, 11], [57, 0],
-    [57, 52], [0, 5], [52, 5], [5, 7],  # frontal
-    [7, 20], [11, 23], [20, 23], [23, 25], [34, 32],
-    [9, 11], [9, 7], [9, 20], [7, 0], [9, 0], [9, 8],  # L-lat
-    [24, 33], [24, 25], [24, 11], [25, 32], [25, 28],
-    [33, 32], [33, 46], [32, 29], [28, 29],  # rear
-    [65, 64], [65, 25], [65, 28], [65, 20], [64, 29],
-    [64, 32], [64, 37], [29, 37], [28, 20],  # new rear
-    [34, 37], [34, 46], [37, 50], [50, 52], [46, 48], [48, 37],
-    [48, 49], [50, 57], [48, 57], [48, 50]
+    (49, 46), (49, 8), (49, 57), (8, 0), (8, 11), (57, 0),
+    (57, 52), (0, 5), (52, 5), (5, 7),  # frontal
+    (7, 20), (11, 23), (20, 23), (23, 25), (34, 32),
+    (9, 11), (9, 7), (9, 20), (7, 0), (9, 0), (9, 8),  # L-lat
+    (24, 33), (24, 25), (24, 11), (25, 32), (25, 28),
+    (33, 32), (33, 46), (32, 29), (28, 29),  # rear
+    (65, 64), (65, 25), (65, 28), (65, 20), (64, 29),
+    (64, 32), (64, 37), (29, 37), (28, 20),  # new rear
+    (34, 37), (34, 46), (37, 50), (50, 52), (46, 48), (48, 37),
+    (48, 49), (50, 57), (48, 57), (48, 50)
 ]
 
 
